summaryrefslogtreecommitdiffstats
path: root/scripts
diff options
context:
space:
mode:
authorSascha Hauer <s.hauer@pengutronix.de>2009-12-15 09:11:09 +0100
committerSascha Hauer <s.hauer@pengutronix.de>2009-12-15 10:18:30 +0100
commita3ffa97f40dc81f2d6b07ee964f2340fe0c1ba97 (patch)
tree7a9076c1a20df00baeadca9a07d4c1f5cd0611e2 /scripts
parentcaa5cec7b1c93d660aa89d24eb160ab18e4eb628 (diff)
downloadbarebox-a3ffa97f40dc81f2d6b07ee964f2340fe0c1ba97.tar.gz
barebox-a3ffa97f40dc81f2d6b07ee964f2340fe0c1ba97.tar.xz
rename U-Boot-v2 project to barebox
This has been done with the following script: find -path ./.git -prune -o -type f -print0 | xargs -0 -r sed -i \ -e 's/u2boot/barebox/g' \ -e 's/U2Boot/barebox/g' \ -e 's/U-boot V2/barebox/g' \ -e 's/u-boot v2/barebox/g' \ -e 's/U-Boot V2/barebox/g' \ -e 's/U-Boot-v2/barebox/g' \ -e 's/U_BOOT/BAREBOX/g' \ -e 's/UBOOT/BAREBOX/g' \ -e 's/uboot/barebox/g' \ -e 's/u-boot/barebox/g' \ -e 's/u_boot/barebox/g' \ -e 's/U-Boot/barebox/g' \ -e 's/U-boot/barebox/g' \ -e 's/U-BOOT/barebox/g' find -path ./.git -prune -o \( -name "*u-boot*" -o -name "*uboot*" -o -name "*u_boot*" \) -print0 | \ xargs -0 -r rename 's/u[-_]?boot/barebox/' It needs some manual fixup following in the next patch Signed-off-by: Sascha Hauer <s.hauer@pengutronix.de>
Diffstat (limited to 'scripts')
-rw-r--r--scripts/.gitignore2
-rw-r--r--scripts/Makefile4
-rw-r--r--scripts/Makefile.lib2
-rw-r--r--scripts/Makefile.modpost8
-rw-r--r--scripts/bareboxenv.c (renamed from scripts/ubootenv.c)6
-rw-r--r--scripts/basic/Makefile2
-rw-r--r--scripts/basic/docproc.c2
-rw-r--r--scripts/gen_netx_image.c16
-rw-r--r--scripts/kconfig/conf.c2
-rw-r--r--scripts/kconfig/confdata.c6
-rw-r--r--scripts/kconfig/mconf.c30
-rw-r--r--scripts/mkimage.c6
-rw-r--r--scripts/mksysmap4
-rw-r--r--scripts/mod/modpost.c4
14 files changed, 47 insertions, 47 deletions
diff --git a/scripts/.gitignore b/scripts/.gitignore
index 4d60d3f1aa..26317b28c2 100644
--- a/scripts/.gitignore
+++ b/scripts/.gitignore
@@ -1,4 +1,4 @@
-ubootenv
+bareboxenv
bin2c
mkimage
kallsyms
diff --git a/scripts/Makefile b/scripts/Makefile
index cb08458ff9..a6829c56be 100644
--- a/scripts/Makefile
+++ b/scripts/Makefile
@@ -2,7 +2,7 @@
# scripts contains sources for various helper programs used throughout
# the kernel for the build process.
# ---------------------------------------------------------------------------
-# kallsyms: Find all symbols in uboot
+# kallsyms: Find all symbols in barebox
# pnmttologo: Convert pnm files to logo files
# conmakehash: Create chartable
# conmakehash: Create arrays for initializing the kernel console tables
@@ -13,7 +13,7 @@ hostprogs-$(CONFIG_VT) += conmakehash
hostprogs-$(CONFIG_PROM_CONSOLE) += conmakehash
hostprogs-y += bin2c
hostprogs-y += mkimage
-hostprogs-y += ubootenv
+hostprogs-y += bareboxenv
hostprogs-$(CONFIG_ARCH_NETX) += gen_netx_image
always := $(hostprogs-y) $(hostprogs-m)
diff --git a/scripts/Makefile.lib b/scripts/Makefile.lib
index 6d26dde242..d7e25630dd 100644
--- a/scripts/Makefile.lib
+++ b/scripts/Makefile.lib
@@ -90,7 +90,7 @@ _c_flags = $(CFLAGS) $(EXTRA_CFLAGS) $(CFLAGS_$(basetarget).o)
_a_flags = $(AFLAGS) $(EXTRA_AFLAGS) $(AFLAGS_$(basetarget).o)
_cpp_flags = $(CPPFLAGS) $(EXTRA_CPPFLAGS) $(CPPFLAGS_$(@F))
-# If building uboot in a separate objtree expand all occurrences
+# If building barebox in a separate objtree expand all occurrences
# of -Idir to -I$(srctree)/dir except for absolute paths (starting with '/').
ifeq ($(KBUILD_SRC),)
diff --git a/scripts/Makefile.modpost b/scripts/Makefile.modpost
index 0278d29a5f..7620c608bc 100644
--- a/scripts/Makefile.modpost
+++ b/scripts/Makefile.modpost
@@ -56,7 +56,7 @@ _modpost: $(if $(KBUILD_MODPOST_NOFINAL), $(modules:.ko:.o),$(modules))
# Step 2), invoke modpost
# Includes step 3,4
-quiet_cmd_modpost = MODPOST $(words $(filter-out uboot FORCE, $^)) modules
+quiet_cmd_modpost = MODPOST $(words $(filter-out barebox FORCE, $^)) modules
cmd_modpost = scripts/mod/modpost \
$(if $(CONFIG_MODVERSIONS),-m) \
$(if $(CONFIG_MODULE_SRCVERSION_ALL),-a,) \
@@ -67,13 +67,13 @@ quiet_cmd_modpost = MODPOST $(words $(filter-out uboot FORCE, $^)) modules
PHONY += __modpost
__modpost: $(modules:.ko=.o) FORCE
- $(call cmd,modpost) $(wildcard uboot) $(filter-out FORCE,$^)
+ $(call cmd,modpost) $(wildcard barebox) $(filter-out FORCE,$^)
quiet_cmd_kernel-mod = MODPOST $@
cmd_kernel-mod = $(cmd_modpost) $@
-PHONY += uboot
-uboot.o: FORCE
+PHONY += barebox
+barebox.o: FORCE
$(call cmd,kernel-mod)
# Declare generated files as targets for modpost
diff --git a/scripts/basic/Makefile b/scripts/basic/Makefile
index a0c0189fbe..4f284df33b 100644
--- a/scripts/basic/Makefile
+++ b/scripts/basic/Makefile
@@ -3,7 +3,7 @@
# The programs listed herein is what is needed to do the basic stuff,
# such as fix dependency file.
# This initial step is needed to avoid files to be recompiled
-# when uboot configuration changes (which is what happens when
+# when barebox configuration changes (which is what happens when
# .config is included by main Makefile.
# ---------------------------------------------------------------------------
# fixdep: Used to generate dependency information during build process
diff --git a/scripts/basic/docproc.c b/scripts/basic/docproc.c
index f71e106206..0d4f5e7d74 100644
--- a/scripts/basic/docproc.c
+++ b/scripts/basic/docproc.c
@@ -1,6 +1,6 @@
/*
* docproc is a simple preprocessor for the template files
- * used as placeholders for the uboot internal documentation.
+ * used as placeholders for the barebox internal documentation.
* docproc is used for documentation-frontend and
* dependency-generator.
* The two usages have in common that they require
diff --git a/scripts/gen_netx_image.c b/scripts/gen_netx_image.c
index 364900b0f3..af279d5485 100644
--- a/scripts/gen_netx_image.c
+++ b/scripts/gen_netx_image.c
@@ -76,7 +76,7 @@ int main(int argc, char *argv[])
struct stat s;
int opt;
unsigned char *buf;
- int bytes, err, uboot_size, ofs, i;
+ int bytes, err, barebox_size, ofs, i;
uint32_t *ptr;
uint32_t checksum = 0;
uint32_t memctrl = 0, sdramctrl = 0, sdramtimctrl = 0, entrypoint = 0, cookie = 0;
@@ -158,22 +158,22 @@ int main(int argc, char *argv[])
exit(1);
}
- uboot_size = s.st_size;
- printf("found u-boot image. size: %d bytes. Using entrypoint 0x%08x\n",uboot_size,entrypoint);
+ barebox_size = s.st_size;
+ printf("found barebox image. size: %d bytes. Using entrypoint 0x%08x\n",barebox_size,entrypoint);
- buf = malloc(uboot_size + sizeof(struct netx_bootblock) + 4);
+ buf = malloc(barebox_size + sizeof(struct netx_bootblock) + 4);
if(!buf) {
perror("malloc");
exit(1);
}
- memset(buf, 0, uboot_size + sizeof(struct netx_bootblock) + 4);
+ memset(buf, 0, barebox_size + sizeof(struct netx_bootblock) + 4);
nb = (struct netx_bootblock *)buf;
nb->cookie = cookie;
nb->ctrl.mem_ctrl = memctrl;
nb->appl_entrypoint = entrypoint;
- nb->appl_size = (uboot_size >> 2);
+ nb->appl_size = (barebox_size >> 2);
nb->appl_start_addr = entrypoint;
nb->signature = NETX_IDENTIFICATION;
@@ -181,7 +181,7 @@ int main(int argc, char *argv[])
nb->config.normal.sdram_timing_ctrl = sdramtimctrl;
ofs = sizeof(struct netx_bootblock);
- bytes = uboot_size;
+ bytes = barebox_size;
while(bytes) {
err = read(fd, buf + ofs, bytes);
@@ -220,7 +220,7 @@ int main(int argc, char *argv[])
exit(1);
}
- bytes = uboot_size + sizeof(struct netx_bootblock);
+ bytes = barebox_size + sizeof(struct netx_bootblock);
ofs = 0;
while(bytes) {
err = write(fd, buf + ofs, bytes);
diff --git a/scripts/kconfig/conf.c b/scripts/kconfig/conf.c
index b82d01af4e..3ce2996d20 100644
--- a/scripts/kconfig/conf.c
+++ b/scripts/kconfig/conf.c
@@ -559,7 +559,7 @@ int main(int ac, char **av)
case ask_silent:
if (stat(".config", &tmpstat)) {
printf(_("***\n"
- "*** You have not yet configured u-boot!\n"
+ "*** You have not yet configured barebox!\n"
"*** (missing .config file)\n"
"***\n"
"*** Please run some configurator (e.g. \"make oldconfig\" or\n"
diff --git a/scripts/kconfig/confdata.c b/scripts/kconfig/confdata.c
index aff5339681..2b8f140635 100644
--- a/scripts/kconfig/confdata.c
+++ b/scripts/kconfig/confdata.c
@@ -440,7 +440,7 @@ int conf_write(const char *name)
fprintf(out, _("#\n"
"# Automatically generated make config: don't edit\n"
- "# U-Boot version: %s\n"
+ "# barebox version: %s\n"
"%s%s"
"#\n"),
sym_get_string_value(sym),
@@ -692,13 +692,13 @@ int conf_write_autoconf(void)
time(&now);
fprintf(out, "#\n"
"# Automatically generated make config: don't edit\n"
- "# U-Boot version: %s\n"
+ "# barebox version: %s\n"
"# %s"
"#\n",
sym_get_string_value(sym), ctime(&now));
fprintf(out_h, "/*\n"
" * Automatically generated C config: don't edit\n"
- " * U-Boot version: %s\n"
+ " * barebox version: %s\n"
" * %s"
" */\n"
"#define AUTOCONF_INCLUDED\n",
diff --git a/scripts/kconfig/mconf.c b/scripts/kconfig/mconf.c
index 4eca540281..4f99c380fe 100644
--- a/scripts/kconfig/mconf.c
+++ b/scripts/kconfig/mconf.c
@@ -29,10 +29,10 @@
static const char mconf_readme[] = N_(
"Overview\n"
"--------\n"
-"Some U-Boot features may be built directly into U-Boot.\n"
+"Some barebox features may be built directly into barebox.\n"
"Some may be made into loadable runtime modules. Some features\n"
"may be completely removed altogether. There are also certain\n"
-"U-Boot parameters which are not really features, but must be\n"
+"barebox parameters which are not really features, but must be\n"
"entered in as decimal or hexadecimal numbers or possibly text.\n"
"\n"
"Menu items beginning with [*], <M> or [ ] represent features\n"
@@ -115,7 +115,7 @@ static const char mconf_readme[] = N_(
"-----------------------------\n"
"Menuconfig supports the use of alternate configuration files for\n"
"those who, for various reasons, find it necessary to switch\n"
-"between different U-Boot configurations.\n"
+"between different barebox configurations.\n"
"\n"
"At the end of the main menu you will find two options. One is\n"
"for saving the current configuration to a file of your choosing.\n"
@@ -148,7 +148,7 @@ static const char mconf_readme[] = N_(
"\n"
"Optional personality available\n"
"------------------------------\n"
-"If you prefer to have all of the U-Boot options listed in a single\n"
+"If you prefer to have all of the barebox options listed in a single\n"
"menu, rather than the default multimenu hierarchy, run the menuconfig\n"
"with MENUCONFIG_MODE environment variable set to single_menu. Example:\n"
"\n"
@@ -200,18 +200,18 @@ setmod_text[] = N_(
"This feature depends on another which has been configured as a module.\n"
"As a result, this feature will be built as a module."),
nohelp_text[] = N_(
- "There is no help available for this U-Boot option.\n"),
+ "There is no help available for this barebox option.\n"),
load_config_text[] = N_(
"Enter the name of the configuration file you wish to load. "
"Accept the name shown to restore the configuration you "
"last retrieved. Leave blank to abort."),
load_config_help[] = N_(
"\n"
- "For various reasons, one may wish to keep several different U-Boot\n"
+ "For various reasons, one may wish to keep several different barebox\n"
"configurations available on a single machine.\n"
"\n"
"If you have saved a previous configuration in a file other than the\n"
- "U-Boot's default, entering the name of the file here will allow you\n"
+ "barebox's default, entering the name of the file here will allow you\n"
"to modify that configuration.\n"
"\n"
"If you are uncertain, then you have probably never used alternate\n"
@@ -221,7 +221,7 @@ save_config_text[] = N_(
"as an alternate. Leave blank to abort."),
save_config_help[] = N_(
"\n"
- "For various reasons, one may wish to keep different U-Boot\n"
+ "For various reasons, one may wish to keep different barebox\n"
"configurations available on a single machine.\n"
"\n"
"Entering a file name here will allow you to later retrieve, modify\n"
@@ -403,7 +403,7 @@ static void set_config_filename(const char *config_filename)
sym = sym_lookup("KERNELVERSION", 0);
sym_calc_value(sym);
size = snprintf(menu_backtitle, sizeof(menu_backtitle),
- _("%s - U-Boot v%s Configuration"),
+ _("%s - barebox v%s Configuration"),
config_filename, sym_get_string_value(sym));
if (size >= sizeof(menu_backtitle))
menu_backtitle[sizeof(menu_backtitle)-1] = '\0';
@@ -919,7 +919,7 @@ int main(int ac, char **av)
if (conf_get_changed())
res = dialog_yesno(NULL,
_("Do you wish to save your "
- "new U-Boot configuration?\n"
+ "new barebox configuration?\n"
"<ESC><ESC> to continue."),
6, 60);
else
@@ -931,20 +931,20 @@ int main(int ac, char **av)
case 0:
if (conf_write(filename)) {
fprintf(stderr, _("\n\n"
- "Error during writing of the U-Boot configuration.\n"
- "Your U-Boot configuration changes were NOT saved."
+ "Error during writing of the barebox configuration.\n"
+ "Your barebox configuration changes were NOT saved."
"\n\n"));
return 1;
}
case -1:
printf(_("\n\n"
- "*** End of U-Boot configuration.\n"
- "*** Execute 'make' to build U-Boot or try 'make help'."
+ "*** End of barebox configuration.\n"
+ "*** Execute 'make' to build barebox or try 'make help'."
"\n\n"));
break;
default:
fprintf(stderr, _("\n\n"
- "Your U-Boot configuration changes were NOT saved."
+ "Your barebox configuration changes were NOT saved."
"\n\n"));
}
diff --git a/scripts/mksysmap b/scripts/mksysmap
index 67f0947021..bacef6a4bb 100644
--- a/scripts/mksysmap
+++ b/scripts/mksysmap
@@ -1,10 +1,10 @@
#!/bin/sh -x
-# Based on the uboot file create the System.map file
+# Based on the barebox file create the System.map file
# System.map is used by module-init tools and some debugging
# tools to retrieve the actual addresses of symbols in the kernel.
#
# Usage
-# mksysmap uboot System.map
+# mksysmap barebox System.map
#####
diff --git a/scripts/mod/modpost.c b/scripts/mod/modpost.c
index 76e61042e3..4075c35d37 100644
--- a/scripts/mod/modpost.c
+++ b/scripts/mod/modpost.c
@@ -91,8 +91,8 @@ static int is_vmlinux(const char *modname)
else
myname = modname;
- return (strcmp(myname, "uboot") == 0) ||
- (strcmp(myname, "uboot.o") == 0);
+ return (strcmp(myname, "barebox") == 0) ||
+ (strcmp(myname, "barebox.o") == 0);
}
void *do_nofail(void *ptr, const char *expr)
diff --git a/scripts/ubootenv.c b/scripts/bareboxenv.c
index 32da113b56..5c7f10e6b9 100644
--- a/scripts/ubootenv.c
+++ b/scripts/bareboxenv.c
@@ -1,5 +1,5 @@
/*
* ubootenv.c - generate or read a U-Boot environment archive
*
* Copyright (c) 2007 Sascha Hauer <s.hauer@pengutronix.de>, Pengutronix
*
@@ -125,8 +125,8 @@ char *concat_subpath_file(const char *path, const char *f)
void usage(char *prgname)
{
printf( "Usage : %s [OPTION] DIRECTORY FILE\n"
- "Load an u-boot environment sector into a directory or\n"
- "save a directory into an u-boot environment sector\n"
+ "Load an barebox environment sector into a directory or\n"
+ "save a directory into an barebox environment sector\n"
"\n"
"options:\n"
" -s save (directory -> environment sector)\n"
@@ -1,5 +1,5 @@
/*
- * ubootenv.c - generate or read a U-Boot environment archive
+ * bareboxenv.c - generate or read a barebox environment archive
*
* Copyright (c) 2007 Sascha Hauer <s.hauer@pengutronix.de>, Pengutronix
diff --git a/scripts/mkimage.c b/scripts/mkimage.c
index ab7d55dc41..240c5cf5d5 100644
--- a/scripts/mkimage.c
+++ b/scripts/mkimage.c
@@ -118,7 +118,7 @@ table_entry_t os_name[] = {
{ IH_OS_SCO, "sco", "SCO", },
{ IH_OS_SOLARIS, "solaris", "Solaris", },
{ IH_OS_SVR4, "svr4", "SVR4", },
- { IH_OS_U_BOOT, "u-boot", "U-Boot", },
+ { IH_OS_BAREBOX, "barebox", "barebox", },
{ IH_OS_VXWORKS, "vxworks", "VxWorks", },
{ -1, "", "", },
};
@@ -269,14 +269,14 @@ NXTARG: ;
if (!eflag) {
ep = addr;
/* If XIP, entry point must be after the U-Boot header */
if (xflag)
ep += sizeof(image_header_t);
}
/*
* If XIP, ensure the entry point is equal to the load address plus
* the size of the U-Boot header.
*/
if (xflag) {
if (ep != addr + sizeof(image_header_t)) {
@@ -269,14 +269,14 @@ NXTARG: ;
if (!eflag) {
ep = addr;
- /* If XIP, entry point must be after the U-Boot header */
+ /* If XIP, entry point must be after the barebox header */
if (xflag)
ep += sizeof(image_header_t);
@@ -269,14 +269,14 @@ NXTARG: ;
/*
* If XIP, ensure the entry point is equal to the load address plus
- * the size of the U-Boot header.
+ * the size of the barebox header.
*/
if (xflag) {